@@ -7,7 +7,9 @@
 	clase <- c("aov", "lm")
 	name.y <- paste(deparse(substitute(y)))
 	name.t <- paste(deparse(substitute(trt)))
+	if(is.null(main))main<-paste(name.y,"~", name.t)
 	if ("aov" %in% class(y) | "lm" %in% class(y)) {
+		if(is.null(main))main<-y$call
 		A <- y$model
 		DFerror <- df.residual(y)
 		MSerror <- deviance(y)/DFerror
@@ -40,8 +42,8 @@
 	Tprob <- qt(1 - alpha/2, DFerror)
 	LCL <- means[, 2] - Tprob * std.err
 	UCL <- means[, 2] + Tprob * std.err
-	means <- data.frame(means, std.err, r = nn[, 2],
-			LCL, UCL,Min.=mi[,2],Max.=ma[,2])
+	means <- data.frame(means, std=sds[,2], r = nn[, 2],
+	LCL, UCL,Min=mi[,2],Max=ma[,2])
 	names(means)[1:2] <- c(name.t, name.y)
 	ntr <- nrow(means)
 	nk <- choose(ntr, 2)
